==> haskell-hls-ormolu-plugin-2.0.0.0-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-ormolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-ormolu-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-ormolu-plugin-2.0.0.0-ExatmgxTULQ7i9sHBV3XmW
key:                  hls-ormolu-plugin-2.0.0.0-ExatmgxTULQ7i9sHBV3XmW
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Ormolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  954a08015434906b32793e00c28784b9
exposed:              True
exposed-modules:      Ide.Plugin.Ormolu
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-ormolu-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-ormolu-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-ormolu-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-ormolu-plugin
hs-libraries:         HShls-ormolu-plugin-2.0.0.0-ExatmgxTULQ7i9sHBV3XmW
depends:
    base-4.17.2.1 filepath-1.4.2.2 ghc-9.4.8 ghc-boot-th-9.4.8
    ghcide-2.0.0.0-EHxX854jmvwD5ulayIxyx6
    hls-plugin-api-2.0.0.0-G44fQLihVWI1U4TjtZEXnI
    lens-5.2.3-J1GK3I4tdtMEzlekK9vBY2
    lsp-1.6.0.0-2EqnYNOWy2LCyRUoXrjR35
    ormolu-0.5.1.0-4oRf3PJXJij8hTVeO6hgNR text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-ormolu-plugin/html/hls-ormolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-ormolu-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-ormolu-plugin-2.0.0.0-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-ormolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-ormolu-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-ormolu-plugin-2.0.0.0-CfbDLX2x3B553Yau42HDIU
key:                  hls-ormolu-plugin-2.0.0.0-CfbDLX2x3B553Yau42HDIU
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Ormolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  66162e8a9604503805ff0be9c0d95e75
exposed:              True
exposed-modules:      Ide.Plugin.Ormolu
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-ormolu-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-ormolu-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-ormolu-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-ormolu-plugin
hs-libraries:         HShls-ormolu-plugin-2.0.0.0-CfbDLX2x3B553Yau42HDIU
depends:
    base-4.17.2.1 filepath-1.4.2.2 ghc-9.4.8 ghc-boot-th-9.4.8
    ghcide-2.0.0.0-6hTfaheG6VuKuwRJZ4Llqv
    hls-plugin-api-2.0.0.0-KVOtPzuMQs9GkM38tQXN9J
    lens-5.2.3-DzkbQ1V4DGJJfQUmuvkfoj
    lsp-1.6.0.0-CSMkkjouyWs2BiL8kksf63
    ormolu-0.5.1.0-AYZRHeO04gZ35g54lEeEMi text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-ormolu-plugin/html/hls-ormolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-ormolu-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
